TEMPLATE = app
VERSION = 1.6.0
INSTALL_PREFIX = /usr
SHARED_PATH = $${INSTALL_PREFIX}/share
DOC_PATH = $${SHARED_PATH}/doc

DEFINES += QOOBAR_VERSION=\\\"$$VERSION\\\"
DEFINES += QOOBAR_SHARED_PATH=\\\"$${SHARED_PATH}/qoobar\\\"
DEFINES += QOOBAR_DOC_PATH=\\\"$${DOC_PATH}/qoobar-doc\\\"

greaterThan(QT_MAJOR_VERSION, 4) {
  message(Using Qt 5)
  QT += widgets
  QT += concurrent
  DEFINES += HAVE_QT5
  unix:!mac:DEFINES += OS_LINUX
  CONFIG += c++11
}

TARGET = qoobar
CONFIG *= warn_on
CONFIG *= release

QT *=  network

# main sources and headers
SOURCES = main.cpp \
    mainwindow.cpp \
    tagseditor.cpp \
    tablewidget.cpp \
    filesrenamer.cpp \
    tagsfiller.cpp \
    tagger.cpp \
    settingsdialog.cpp \
    tab.cpp \
    completerdelegate.cpp \
    lineedit.cpp \
    splitdialog.cpp \
    qoobarglobals.cpp \
    undoactions.cpp \
    tagrender.cpp \
    imagedialog.cpp \
    tabwidget.cpp \
    imagebox.cpp \
    treewidget.cpp \
    legendbutton.cpp \
    displayedtagsdialog.cpp \
    application.cpp \
    discidhelper.cpp \
    texteditdelegate.cpp \
    stringroutines.cpp \
    id3v1stringhandler.cpp \
    newtagdialog.cpp \
    schemeeditor.cpp \
    configpages.cpp \
    releaseinfowidget.cpp \
    taggingscheme.cpp \
    completionsdialog.cpp \
    macsplitter.cpp \
    replaygaindialog.cpp \
    mp3tagsdialog.cpp \
    processlinemaker.cpp \
    statusbar.cpp \
    searchpanel.cpp \
    highlightdelegate.cpp \
    filedelegatehighlighter.cpp \
    checkableheaderview.cpp \
    sections.cpp \
    sectiondelegatehighlighter.cpp \
    delegatehighlighter.cpp \
    coverimage.cpp \
    tagsreaderwriter.cpp \
    corenetworksearch.cpp \
    tagparser.cpp \
    placeholders.cpp \
    fancylineedit.cpp \
    clearlineedit.cpp \
    model.cpp \
    replaygainer.cpp \
    columnsdialog.cpp \
    cuesplitter.cpp

HEADERS = mainwindow.h \
    tagseditor.h \
    tablewidget.h \
    filesrenamer.h \
    tagsfiller.h \
    tagger.h \
    settingsdialog.h \
    tab.h \
    completerdelegate.h \
    lineedit.h \
    splitdialog.h \
    qoobarglobals.h \
    undoactions.h \
    tagrender.h \
    imagedialog.h \
    tabwidget.h \
    imagebox.h \
    treewidget.h \
    searchresults.h \
    legendbutton.h \
    displayedtagsdialog.h \
    application.h \
    discidhelper.h \
    texteditdelegate.h \
    stringroutines.h \
    id3v1stringhandler.h \
    newtagdialog.h \
    schemeeditor.h \
    configpages.h \
    releaseinfowidget.h \
    taggingscheme.h \
    completionsdialog.h \
    applicationpaths.h \
    macsplitter.h \
    replaygaindialog.h \
    mp3tagsdialog.h \
    processlinemaker.h \
    statusbar.h \
    searchpanel.h \
    highlightdelegate.h \
    delegatehighlighter.h \
    filedelegatehighlighter.h \
    checkableheaderview.h \
    sections.h \
    sectiondelegatehighlighter.h \
    iqoobarplugin.h \
    coverimage.h \
    tagsreaderwriter.h \
    corenetworksearch.h \
    enums.h \
    tagparser.h \
    placeholders.h \
    idownloadplugin.h \
    fancylineedit.h \
    clearlineedit.h \
    model.h \
    replaygainer.h \
    columnsdialog.h \
    cuesplitter.h

lessThan(QT_MAJOR_VERSION, 5) {
    SOURCES += ereilin/json.cpp
    HEADERS += ereilin/json.h
}

RESOURCES += qoobar.qrc
TRANSLATIONS = qoobar_ru.ts \
    qoobar_en.ts \
    qoobar_de.ts \
    qoobar_it.ts \
    qoobar_fr.ts \
    qoobar_pl.ts \
    qoobar_nl.ts

system(lupdate qoobar_app.pro&&lrelease qoobar_app.pro)

INCLUDEPATH += taglib
HEADERS += taglib/*.h   \
           taglib/ape/*.h \
           taglib/asf/*.h \
           taglib/flac/*.h \
           taglib/mp4/*.h \
           taglib/mpc/*.h \
           taglib/mpeg/*.h \
           taglib/mpeg/id3v1/*.h \
           taglib/mpeg/id3v2/*.h \
           taglib/mpeg/id3v2/frames/*.h \
           taglib/ogg/*.h \
           taglib/ogg/flac/*.h \
           taglib/ogg/speex/*.h \
           taglib/ogg/vorbis/*.h \
           taglib/riff/*.h \
           taglib/riff/aiff/*.h \
           taglib/riff/wav/*.h \
           taglib/toolkit/*.h \
           taglib/trueaudio/*.h \
           taglib/wavpack/*.h \
           taglib/ogg/opus/*.h

SOURCES += taglib/*.cpp \
           taglib/ape/*.cpp \
           taglib/asf/*.cpp \
           taglib/flac/*.cpp \
           taglib/mp4/*.cpp \
           taglib/mpc/*.cpp \
           taglib/mpeg/*.cpp \
           taglib/mpeg/id3v1/*.cpp \
           taglib/mpeg/id3v2/*.cpp \
           taglib/mpeg/id3v2/frames/*.cpp \
           taglib/ogg/*.cpp \
           taglib/ogg/flac/*.cpp \
           taglib/ogg/speex/*.cpp \
           taglib/ogg/vorbis/*.cpp \
           taglib/riff/*.cpp \
           taglib/riff/aiff/*.cpp \
           taglib/riff/wav/*.cpp \
           taglib/toolkit/*.cpp \
           taglib/trueaudio/*.cpp \
           taglib/wavpack/*.cpp \
           taglib/ogg/opus/*.cpp

DEFINES += QOOBAR_NO_PROPERTY_MAPS
DEFINES += HAVE_ZLIB

CONFIG(release, debug|release):BUILD_DIR = ../../release
CONFIG(debug, debug|release):BUILD_DIR = ../../debug

DESTDIR = $$BUILD_DIR
OBJECTS_DIR = $$BUILD_DIR
RCC_DIR = $$BUILD_DIR
MOC_DIR = $$BUILD_DIR


INCLUDEPATH += tclap
#SEARCHPATH += tclap
HEADERS += tclap/*.h
HEADERS += argsparser.h
SOURCES += argsparser.cpp



unix {
!mac {
    INCLUDEPATH += libebur128
    HEADERS += libebur128/*.h
    SOURCES += libebur128/*.cpp
    SOURCES += libebur128/*.c

#    PKGCONFIG += glib-2.0
#    PKGCONFIG += libavcodec
#    PKGCONFIG += libavformat
#    PKGCONFIG += libavutil
#    DEFINES += USE_FFMPEG

    PKGCONFIG += gstreamer-app-0.10
    PKGCONFIG += gstreamer-audio-0.10
    DEFINES += WITH_DECODING

    message(Linux build)
    EXEC_PATH = $${INSTALL_PREFIX}/bin
    PIXMAP_PATH = $${SHARED_PATH}/pixmaps
    MAN_PATH = $${SHARED_PATH}/man/man1
    DESKTOP_PATH = $${SHARED_PATH}/applications

    HEADERS += linuxpaths.h

    # targets for binary package
    icon.path = $$PIXMAP_PATH
    icon.files = icons/qoobar.png
    resources.path = $${SHARED_PATH}/qoobar
    resources.files = *.qm *.txt
    schemes.path = $${SHARED_PATH}/qoobar/schemes
    schemes.files = schemes/*.xml
    completions.files = completions/*.txt
    completions.path = $${SHARED_PATH}/qoobar/completions
    manfiles.path = $$MAN_PATH
    manfiles.files = ../../qoobar.1
    desktop.path = $$DESKTOP_PATH
    desktop.files = ../../qoobar.desktop
    target.path = $$EXEC_PATH
    docfiles.path = $${DOC_PATH}/qoobar
    docfiles.files = ../../README*
    INSTALLS += target icon docfiles resources
    INSTALLS += schemes desktop manfiles completions

    # documentation
    htmldocfiles.path = $${DOC_PATH}/qoobar-doc/html
    htmldocfiles.files = ../../html/*
    htmldocfiles_html_en.path = $${DOC_PATH}/qoobar-doc/html/en
    htmldocfiles_html_en.files = ../../html/en/*.htm
    htmldocfiles_imgs_en.path = $${DOC_PATH}/qoobar-doc/html/en/images
    htmldocfiles_imgs_en.files = ../../html/en/images/*.png
    INSTALLS += htmldocfiles htmldocfiles_html_en htmldocfiles_imgs_en

    CONFIG += link_pkgconfig qt
    PKGCONFIG += zlib
}
}

win32|win {
    HEADERS += windowspaths.h
    INCLUDEPATH += K:/My/programming/sources/libz-1.2.3-1-mingw32-dev/include
    LIBS += K:/My/programming/sources/libz-1.2.3-1-mingw32-dev/lib/libz.dll.a

    RC_FILE = qoobar.rc
}

os2 {
    INSTALL_PREFIX = /qoobar # <- edit this macro to change the installation root
    SHARED_PATH = $${INSTALL_PREFIX}
    DOC_PATH = $${SHARED_PATH}/doc
    EXEC_PATH = $${INSTALL_PREFIX}
    #PIXMAP_PATH = $${SHARED_PATH}/pixmaps
    MAN_PATH = $${SHARED_PATH}/man
    #DESKTOP_PATH = $${SHARED_PATH}/applications

    # targets for binary package
    #icon.path = $$PIXMAP_PATH
    #icon.files = icons/qoobar.png
    resources.path = $${SHARED_PATH}
    resources.files = *.qm *.txt
    schemes.path = $${SHARED_PATH}/schemes
    schemes.files = schemes/*.xml
    completions.files = completions/*.txt
    completions.path = $${SHARED_PATH}/completions
    manfiles.path = $$MAN_PATH
    manfiles.files = qoobar.1
    #desktop.path = $$DESKTOP_PATH
    #desktop.files = qoobar.desktop
    target.path = $$EXEC_PATH
    docfiles.path = $${DOC_PATH}
    docfiles.files = README*
    INSTALLS += target
    #INSTALLS += icon desktop
    INSTALLS += docfiles resources
    INSTALLS += schemes manfiles completions

    # documentation
    htmldocfiles.path = $${DOC_PATH}/html
    htmldocfiles.files = html/*
    htmldocfiles_html_en.path = $${DOC_PATH}/html/en
    htmldocfiles_html_en.files = html/en/*.htm
    htmldocfiles_imgs_en.path = $${DOC_PATH}/html/en/images
    htmldocfiles_imgs_en.files = html/en/images/*.png
    INSTALLS += htmldocfiles htmldocfiles_html_en htmldocfiles_imgs_en

    HEADERS += os2paths.h

    RC_FILE = qoobar_os2.rc
    INCLUDEPATH += . \
       o:/usr/local/include
}

mac|macx {
    message(Mac OS build)
    HEADERS += macpaths.h

    LIBS += -lz

    LIBS += -F../../mac_os/ -framework discid
    INCLUDEPATH += ../../mac_os/discid.framework/Versions/A/Headers
    DEPENDPATH += ../../mac_os/discid.framework/Versions/A/Headers

    ICON = qoobar.icns
    INSTALL_PATH = $$DESTDIR/qoobar.app/Contents

    icon.path = $$INSTALL_PATH/Resources
    icon.files = qoobar.icns
    resources.path = $$INSTALL_PATH/Resources
    resources.files = *.qm *.txt
    schemes.path = $$INSTALL_PATH/Resources/schemes
    schemes.files = schemes/*.xml
    completions.path = $$INSTALL_PATH/Resources/completions
    completions.files = completions/*.txt

    INSTALLS += icon resources schemes completions

    # documentation
    htmldocfiles.path = $$INSTALL_PATH/Resources/html
    htmldocfiles.files = ../../html/*
    htmldocfiles_html_en.path = $$INSTALL_PATH/Resources/html/en
    htmldocfiles_html_en.files = ../../html/en/*.htm
    htmldocfiles_imgs_en.path = $$INSTALL_PATH/Resources/html/en/images
    htmldocfiles_imgs_en.files = ../../html/en/images/*.png
    INSTALLS += htmldocfiles htmldocfiles_html_en htmldocfiles_imgs_en

    discid_framework.path = $$INSTALL_PATH/Frameworks/discid.framework
    discid_framework.files = ../../mac_os/discid.framework/*
    discid_framework.extra= $$[QT_INSTALL_BINS]/macdeployqt $$DESTDIR/qoobar.app
    utilities.path = $$INSTALL_PATH/Resources
    utilities.files = ../../mac_os/shntool ../../mac_os/flac ../../mac_os/mac \
    ../../mac_os/mp3gain ../../mac_os/enca ../../mac_os/vorbisgain ../../mac_os/metaflac \
    ../../mac_os/replaygain ../../mac_os/mppdec ../../mac_os/aacgain ../../mac_os/wvgain \
    ../../mac_os/*.dylib

    INSTALLS += discid_framework utilities
}
